summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kolibs/KoPageLayoutColumns.h')
-rw-r--r--kexi/3rdparty/kolibs/KoPageLayoutColumns.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kexi/3rdparty/kolibs/KoPageLayoutColumns.h b/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
index be0a4a493..016eb767f 100644
--- a/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
+++ b/kexi/3rdparty/kolibs/KoPageLayoutColumns.h
@@ -19,14 +19,14 @@
// Description: Page Layout Dialog (sources)
-#ifndef kopagelayoutcolumns_h
-#define kopagelayoutcolumns_h
+#ifndef kopagetqlayoutcolumns_h
+#define kopagetqlayoutcolumns_h
#include <KoUnit.h>
#include <KoPageLayout.h>
#include <KoPageLayoutColumnsBase.h>
-class QWidget;
+class TQWidget;
class KoUnitDoubleSpinBox;
class KoPagePreview;
@@ -35,22 +35,23 @@ class KoPagePreview;
*/
class KoPageLayoutColumns : public KoPageLayoutColumnsBase {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Contructor
* @param parent the parent widget
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show
* @param layout the page layout that the preview should be initialzed with.
*/
- KoPageLayoutColumns(QWidget *parent, const KoColumns& columns, KoUnit::Unit unit, const KoPageLayout& layout);
+ KoPageLayoutColumns(TQWidget *tqparent, const KoColumns& columns, KoUnit::Unit unit, const KoPageLayout& tqlayout);
/**
* Update the page preview widget with the param layout.
* @param layout the new layout
*/
- void setLayout(KoPageLayout &layout);
+ void setLayout(KoPageLayout &tqlayout);
public slots:
/**
@@ -35,22 +35,23 @@ class KoPagePreview;
/**
* Contructor
- * @param parent the parent widget
+ * @param tqparent the tqparent widget
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show
@@ -35,22 +35,23 @@ class KoPagePreview;
* @param columns the KoColumns data structure that this dialog should be initialzed with
* @param unit the unit-type (mm/cm/inch) that the dialog should show
- * @param layout the page layout that the preview should be initialzed with.
+ * @param tqlayout the page tqlayout that the preview should be initialzed with.
*/
@@ -35,22 +35,23 @@ class KoPagePreview;
/**
- * Update the page preview widget with the param layout.
- * @param layout the new layout
+ * Update the page preview widget with the param tqlayout.
+ * @param tqlayout the new tqlayout
*/